.. _api_reference:

Module Reference
===================

.. currentmodule:: xgboost_distribution

XGBDistribution
-------------------

.. autosummary::
    :toctree: api/

    xgboost_distribution.XGBDistribution
    :members:
